==> pyelection-0.0.1.tar.gz: pyelection-0.0.1/setup.py <==
#!/usr/bin/env python

# Copyright (c) 2018, Jay Kubo
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from os import chdir, path
from setuptools import setup, find_packages

chdir(path.split(path.abspath(__file__))[0])

with open('README.md', 'r') as fh:
    long_description = fh.read()

setup(**{
    'name': 'pyelection',
    'provides': ['pyelection'],
    'install_requires': [
        'requests>=2.0',
        'beautifulsoup4>=4.0',
        'lxml>=4.2'
    ],
    'packages': find_packages(),
    'include_package_data': True,
    'version': '0.0.1',
    'description': 'Obtain historical US presidential election data',
    'long_description': long_description,
    'long_description_content_type': "text/markdown",
    'author': 'Jay Kubo',
    'author_email': 'jaykubo@outlook.com',
    'url': 'https://github.com/jkubo/pyelection',
    'classifiers': [
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python'
     ]
})

==> pyelection-0.0.2.tar.gz: pyelection-0.0.2/setup.py <==
#!/usr/bin/env python

# Copyright (c) 2018, Jay Kubo
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from os import chdir, path
from setuptools import setup, find_packages

chdir(path.split(path.abspath(__file__))[0])

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='pyelection',
    provides=['pyelection'],
    install_requires=[
        'requests>=2.0',
        'beautifulsoup4>=4.0',
        'lxml>=4.2'
    ],
    packages=find_packages(),
    include_package_data=True,
    version='0.0.2',
    description='Obtain historical US presidential election data',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Jay Kubo',
    author_email='jaykubo@outlook.com',
    url='https://github.com/jkubo/pyelection',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python'
     ]
)
